@@ -17,7 +17,7 @@ coulombs = make_compound_unit(
     """
 )
 
-generated = si_unit(base_unit=coulombs, short_doc="""The base unit is :class:`coulombs`.""")
+generated = si_unit(base_unit=coulombs)
 globals().update(generated)
 
 fundamental_charge = make_compound_unit(
@@ -31,7 +31,8 @@ fundamental_charge = make_compound_unit(
 )
 
 __all__ = [
-              "Charge",
-              "coulombs",
-              "fundamental_charge",
-          ] + list(generated.keys())
+    "Charge",
+    "coulombs",
+    "fundamental_charge",
+    *generated.keys()
+]
