@@ -13,9 +13,11 @@ amperes = make_unit(
     """
 )
 
-generated = si_unit(base_unit=amperes, short_doc="The :class:`ampere` is the SI base unit.")
+generated = si_unit(base_unit=amperes)
+globals().update(generated)
 
 __all__ = [
-              "Current",
-              "amperes",
-          ] + list(generated.keys())
+    "Current",
+    "amperes",
+    *generated.keys()
+]
